@@ -264,17 +264,7 @@ sub _getForeignKeys{
 }# getForeignKeys
 
 1;
-
-
-=pod
-
-=head1 NAME
-
-FabForce::DBDesigner4::Table
-
-=head1 VERSION
-
-version 0.33
+__END__
 
 =head1 DBDesigner4::Table
 
@@ -289,7 +279,7 @@ Methods of the table-objects
   $table->name('tablename');
   # get the tablename
   my $name = $table->name();
-
+  
 =head2 columns
 
   # set the tablecolumns
@@ -298,17 +288,17 @@ Methods of the table-objects
   
   # get the columns
   print $_,"\n" for($table->columns());
-
+  
 =head2 columnType
 
   # get datatype of n-th column (i.e. 3rd column)
   my $datatype = $table->columnType(3);
-
+  
 =head2 columnInfo
 
   # get info about n-th column (i.e. 4th column)
   print Dumper($table->columnInfo(4));
-
+  
 =head2 stringsToTableCols
 
   # maps column information to hash (needed for columns())
@@ -369,20 +359,4 @@ Methods of the table-objects
   use Data::Dumper;
   print Dumper \%foreign_keys;
 
-=head1 AUTHOR
-
-Renee Baecker <module@renee-baecker.de>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2010 by Renee Baecker.
-
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
-
 =cut
-
-
-__END__
-
